==> apache-calcite-1.19.0-src.tar.gz: apache-calcite-1.19.0-src/core/src/main/java/org/apache/calcite/interpreter/FilterNode.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.calcite.interpreter;

import org.apache.calcite.rel.core.Filter;

import com.google.common.collect.ImmutableList;

/**
 * Interpreter node that implements a
 * {@link org.apache.calcite.rel.core.Filter}.
 */
public class FilterNode extends AbstractSingleNode<Filter> {
  private final Scalar condition;
  private final Context context;

  public FilterNode(Compiler compiler, Filter rel) {
    super(compiler, rel);
    this.condition =
        compiler.compile(ImmutableList.of(rel.getCondition()),
            rel.getRowType());
    this.context = compiler.createContext();
  }

  public void run() throws InterruptedException {
    Row row;
    while ((row = source.receive()) != null) {
      context.values = row.getValues();
      Boolean b = (Boolean) condition.execute(context);
      if (b != null && b) {
        sink.send(row);
      }
    }
  }
}

// End FilterNode.java

==> apache-calcite-1.40.0-src.tar.gz: apache-calcite-1.40.0-src/core/src/main/java/org/apache/calcite/interpreter/FilterNode.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.calcite.interpreter;

import org.apache.calcite.rel.core.Filter;

import com.google.common.collect.ImmutableList;

/**
 * Interpreter node that implements a
 * {@link org.apache.calcite.rel.core.Filter}.
 */
public class FilterNode extends AbstractSingleNode<Filter> {
  private final Scalar condition;
  private final Context context;

  public FilterNode(Compiler compiler, Filter rel) {
    super(compiler, rel);
    this.condition =
        compiler.compile(ImmutableList.of(rel.getCondition()),
            rel.getRowType());
    this.context = compiler.createContext();
  }

  @Override public void run() throws InterruptedException {
    Row row;
    while ((row = source.receive()) != null) {
      context.values = row.getValues();
      Boolean b = (Boolean) condition.execute(context);
      if (b != null && b) {
        sink.send(row);
      }
    }
  }
}
